==> haskell-fgl-arbitrary-0.2.0.6-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-6GFDCl4UGw44YmHlvJHM0W
key:                  fgl-arbitrary-0.2.0.6-6GFDCl4UGw44YmHlvJHM0W
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  ced4a0898042fabe70279f1c6ef4efbe
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.0.1/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/fgl-arbitrary-0.2.0.6
hs-libraries:         HSfgl-arbitrary-0.2.0.6-6GFDCl4UGw44YmHlvJHM0W
depends:
    QuickCheck-2.14.2-3f9Gw3UEGqTK3AyHIcW3dz base-4.15.0.0
    fgl-5.7.0.3-KVkA9k3t5D032W6Sy3xn17

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-3yDN0UXmasI1iSvtrOOiRp
key:                  fgl-arbitrary-0.2.0.6-3yDN0UXmasI1iSvtrOOiRp
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  857acd6473f68be35949b8ce1f6213ff
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.0.1/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/fgl-arbitrary-0.2.0.6
hs-libraries:         HSfgl-arbitrary-0.2.0.6-3yDN0UXmasI1iSvtrOOiRp
depends:
    QuickCheck-2.14.2-89heecYdZ4rHgyVueE4GTO base-4.15.0.0
    fgl-5.7.0.3-8ESQqRplHSbLIpbDYvLxn0

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
